# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dropsonde/pb/envelope.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dropsonde.pb import http_pb2 as dropsonde_dot_pb_dot_http__pb2
from dropsonde.pb import log_pb2 as dropsonde_dot_pb_dot_log__pb2
from dropsonde.pb import metric_pb2 as dropsonde_dot_pb_dot_metric__pb2
from dropsonde.pb import error_pb2 as dropsonde_dot_pb_dot_error__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dropsonde/pb/envelope.proto',
  package='events',
  syntax='proto2',
  serialized_pb=_b('\n\x1b\x64ropsonde/pb/envelope.proto\x12\x06\x65vents\x1a\x17\x64ropsonde/pb/http.proto\x1a\x16\x64ropsonde/pb/log.proto\x1a\x19\x64ropsonde/pb/metric.proto\x1a\x18\x64ropsonde/pb/error.proto\"\xde\x04\n\x08\x45nvelope\x12\x0e\n\x06origin\x18\x01 \x02(\t\x12-\n\teventType\x18\x02 \x02(\x0e\x32\x1a.events.Envelope.EventType\x12\x11\n\ttimestamp\x18\x06 \x01(\x03\x12\x12\n\ndeployment\x18\r \x01(\t\x12\x0b\n\x03job\x18\x0e \x01(\t\x12\r\n\x05index\x18\x0f \x01(\t\x12\n\n\x02ip\x18\x10 \x01(\t\x12(\n\x04tags\x18\x11 \x03(\x0b\x32\x1a.events.Envelope.TagsEntry\x12,\n\rhttpStartStop\x18\x07 \x01(\x0b\x32\x15.events.HttpStartStop\x12&\n\nlogMessage\x18\x08 \x01(\x0b\x32\x12.events.LogMessage\x12(\n\x0bvalueMetric\x18\t \x01(\x0b\x32\x13.events.ValueMetric\x12*\n\x0c\x63ounterEvent\x18\n \x01(\x0b\x32\x14.events.CounterEvent\x12\x1c\n\x05\x65rror\x18\x0b \x01(\x0b\x32\r.events.Error\x12\x30\n\x0f\x63ontainerMetric\x18\x0c \x01(\x0b\x32\x17.events.ContainerMetric\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"q\n\tEventType\x12\x11\n\rHttpStartStop\x10\x04\x12\x0e\n\nLogMessage\x10\x05\x12\x0f\n\x0bValueMetric\x10\x06\x12\x10\n\x0c\x43ounterEvent\x10\x07\x12\t\n\x05\x45rror\x10\x08\x12\x13\n\x0f\x43ontainerMetric\x10\tB1\n!org.cloudfoundry.dropsonde.eventsB\x0c\x45ventFactory')
  ,
  dependencies=[dropsonde_dot_pb_dot_http__pb2.DESCRIPTOR,dropsonde_dot_pb_dot_log__pb2.DESCRIPTOR,dropsonde_dot_pb_dot_metric__pb2.DESCRIPTOR,dropsonde_dot_pb_dot_error__pb2.DESCRIPTOR,])



_ENVELOPE_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='events.Envelope.EventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HttpStartStop', index=0, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LogMessage', index=1, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ValueMetric', index=2, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CounterEvent', index=3, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Error', index=4, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ContainerMetric', index=5, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=635,
  serialized_end=748,
)
_sym_db.RegisterEnumDescriptor(_ENVELOPE_EVENTTYPE)


_ENVELOPE_TAGSENTRY = _descriptor.Descriptor(
  name='TagsEntry',
  full_name='events.Envelope.TagsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='events.Envelope.TagsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='events.Envelope.TagsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=590,
  serialized_end=633,
)

_ENVELOPE = _descriptor.Descriptor(
  name='Envelope',
  full_name='events.Envelope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='events.Envelope.origin', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventType', full_name='events.Envelope.eventType', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=4,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='events.Envelope.timestamp', index=2,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deployment', full_name='events.Envelope.deployment', index=3,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='job', full_name='events.Envelope.job', index=4,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='events.Envelope.index', index=5,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ip', full_name='events.Envelope.ip', index=6,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tags', full_name='events.Envelope.tags', index=7,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='httpStartStop', full_name='events.Envelope.httpStartStop', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logMessage', full_name='events.Envelope.logMessage', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueMetric', full_name='events.Envelope.valueMetric', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='counterEvent', full_name='events.Envelope.counterEvent', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='events.Envelope.error', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='containerMetric', full_name='events.Envelope.containerMetric', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ENVELOPE_TAGSENTRY, ],
  enum_types=[
    _ENVELOPE_EVENTTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=142,
  serialized_end=748,
)

_ENVELOPE_TAGSENTRY.containing_type = _ENVELOPE
_ENVELOPE.fields_by_name['eventType'].enum_type = _ENVELOPE_EVENTTYPE
_ENVELOPE.fields_by_name['tags'].message_type = _ENVELOPE_TAGSENTRY
_ENVELOPE.fields_by_name['httpStartStop'].message_type = dropsonde_dot_pb_dot_http__pb2._HTTPSTARTSTOP
_ENVELOPE.fields_by_name['logMessage'].message_type = dropsonde_dot_pb_dot_log__pb2._LOGMESSAGE
_ENVELOPE.fields_by_name['valueMetric'].message_type = dropsonde_dot_pb_dot_metric__pb2._VALUEMETRIC
_ENVELOPE.fields_by_name['counterEvent'].message_type = dropsonde_dot_pb_dot_metric__pb2._COUNTEREVENT
_ENVELOPE.fields_by_name['error'].message_type = dropsonde_dot_pb_dot_error__pb2._ERROR
_ENVELOPE.fields_by_name['containerMetric'].message_type = dropsonde_dot_pb_dot_metric__pb2._CONTAINERMETRIC
_ENVELOPE_EVENTTYPE.containing_type = _ENVELOPE
DESCRIPTOR.message_types_by_name['Envelope'] = _ENVELOPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Envelope = _reflection.GeneratedProtocolMessageType('Envelope', (_message.Message,), dict(

  TagsEntry = _reflection.GeneratedProtocolMessageType('TagsEntry', (_message.Message,), dict(
    DESCRIPTOR = _ENVELOPE_TAGSENTRY,
    __module__ = 'dropsonde.pb.envelope_pb2'
    # @@protoc_insertion_point(class_scope:events.Envelope.TagsEntry)
    ))
  ,
  DESCRIPTOR = _ENVELOPE,
  __module__ = 'dropsonde.pb.envelope_pb2'
  # @@protoc_insertion_point(class_scope:events.Envelope)
  ))
_sym_db.RegisterMessage(Envelope)
_sym_db.RegisterMessage(Envelope.TagsEntry)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!org.cloudfoundry.dropsonde.eventsB\014EventFactory'))
_ENVELOPE_TAGSENTRY.has_options = True
_ENVELOPE_TAGSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)
