# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dropsonde/pb/http.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dropsonde.pb import uuid_pb2 as dropsonde_dot_pb_dot_uuid__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='dropsonde/pb/http.proto',
  package='events',
  syntax='proto2',
  serialized_pb=_b('\n\x17\x64ropsonde/pb/http.proto\x12\x06\x65vents\x1a\x17\x64ropsonde/pb/uuid.proto\"\xe8\x02\n\rHttpStartStop\x12\x16\n\x0estartTimestamp\x18\x01 \x02(\x03\x12\x15\n\rstopTimestamp\x18\x02 \x02(\x03\x12\x1f\n\trequestId\x18\x03 \x02(\x0b\x32\x0c.events.UUID\x12\"\n\x08peerType\x18\x04 \x02(\x0e\x32\x10.events.PeerType\x12\x1e\n\x06method\x18\x05 \x02(\x0e\x32\x0e.events.Method\x12\x0b\n\x03uri\x18\x06 \x02(\t\x12\x15\n\rremoteAddress\x18\x07 \x02(\t\x12\x11\n\tuserAgent\x18\x08 \x02(\t\x12\x12\n\nstatusCode\x18\t \x02(\x05\x12\x15\n\rcontentLength\x18\n \x02(\x03\x12#\n\rapplicationId\x18\x0c \x01(\x0b\x32\x0c.events.UUID\x12\x15\n\rinstanceIndex\x18\r \x01(\x05\x12\x12\n\ninstanceId\x18\x0e \x01(\t\x12\x11\n\tforwarded\x18\x0f \x03(\t*\"\n\x08PeerType\x12\n\n\x06\x43lient\x10\x01\x12\n\n\x06Server\x10\x02*\xc6\x04\n\x06Method\x12\x07\n\x03GET\x10\x01\x12\x08\n\x04POST\x10\x02\x12\x07\n\x03PUT\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x08\n\x04HEAD\x10\x05\x12\x07\n\x03\x41\x43L\x10\x06\x12\x14\n\x10\x42\x41SELINE_CONTROL\x10\x07\x12\x08\n\x04\x42IND\x10\x08\x12\x0b\n\x07\x43HECKIN\x10\t\x12\x0c\n\x08\x43HECKOUT\x10\n\x12\x0b\n\x07\x43ONNECT\x10\x0b\x12\x08\n\x04\x43OPY\x10\x0c\x12\t\n\x05\x44\x45\x42UG\x10\r\x12\t\n\x05LABEL\x10\x0e\x12\x08\n\x04LINK\x10\x0f\x12\x08\n\x04LOCK\x10\x10\x12\t\n\x05MERGE\x10\x11\x12\x0e\n\nMKACTIVITY\x10\x12\x12\x0e\n\nMKCALENDAR\x10\x13\x12\t\n\x05MKCOL\x10\x14\x12\x11\n\rMKREDIRECTREF\x10\x15\x12\x0f\n\x0bMKWORKSPACE\x10\x16\x12\x08\n\x04MOVE\x10\x17\x12\x0b\n\x07OPTIONS\x10\x18\x12\x0e\n\nORDERPATCH\x10\x19\x12\t\n\x05PATCH\x10\x1a\x12\x07\n\x03PRI\x10\x1b\x12\x0c\n\x08PROPFIND\x10\x1c\x12\r\n\tPROPPATCH\x10\x1d\x12\n\n\x06REBIND\x10\x1e\x12\n\n\x06REPORT\x10\x1f\x12\n\n\x06SEARCH\x10 \x12\x0e\n\nSHOWMETHOD\x10!\x12\r\n\tSPACEJUMP\x10\"\x12\x0e\n\nTEXTSEARCH\x10#\x12\t\n\x05TRACE\x10$\x12\t\n\x05TRACK\x10%\x12\n\n\x06UNBIND\x10&\x12\x0e\n\nUNCHECKOUT\x10\'\x12\n\n\x06UNLINK\x10(\x12\n\n\x06UNLOCK\x10)\x12\n\n\x06UPDATE\x10*\x12\x15\n\x11UPDATEREDIRECTREF\x10+\x12\x13\n\x0fVERSION_CONTROL\x10,B0\n!org.cloudfoundry.dropsonde.eventsB\x0bHttpFactory')
  ,
  dependencies=[dropsonde_dot_pb_dot_uuid__pb2.DESCRIPTOR,])

_PEERTYPE = _descriptor.EnumDescriptor(
  name='PeerType',
  full_name='events.PeerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Client', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='Server', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=423,
  serialized_end=457,
)
_sym_db.RegisterEnumDescriptor(_PEERTYPE)

PeerType = enum_type_wrapper.EnumTypeWrapper(_PEERTYPE)
_METHOD = _descriptor.EnumDescriptor(
  name='Method',
  full_name='events.Method',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GET', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POST', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUT', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEAD', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACL', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BASELINE_CONTROL', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIND', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECKIN', index=8, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECKOUT', index=9, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECT', index=10, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COPY', index=11, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DEBUG', index=12, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LABEL', index=13, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LINK', index=14, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCK', index=15, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MERGE', index=16, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MKACTIVITY', index=17, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MKCALENDAR', index=18, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MKCOL', index=19, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MKREDIRECTREF', index=20, number=21,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MKWORKSPACE', index=21, number=22,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVE', index=22, number=23,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPTIONS', index=23, number=24,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ORDERPATCH', index=24, number=25,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PATCH', index=25, number=26,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRI', index=26, number=27,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROPFIND', index=27, number=28,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROPPATCH', index=28, number=29,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REBIND', index=29, number=30,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REPORT', index=30, number=31,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEARCH', index=31, number=32,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOWMETHOD', index=32, number=33,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SPACEJUMP', index=33, number=34,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEXTSEARCH', index=34, number=35,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=35, number=36,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACK', index=36, number=37,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNBIND', index=37, number=38,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNCHECKOUT', index=38, number=39,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNLINK', index=39, number=40,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNLOCK', index=40, number=41,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATE', index=41, number=42,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UPDATEREDIRECTREF', index=42, number=43,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VERSION_CONTROL', index=43, number=44,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=460,
  serialized_end=1042,
)
_sym_db.RegisterEnumDescriptor(_METHOD)

Method = enum_type_wrapper.EnumTypeWrapper(_METHOD)
Client = 1
Server = 2
GET = 1
POST = 2
PUT = 3
DELETE = 4
HEAD = 5
ACL = 6
BASELINE_CONTROL = 7
BIND = 8
CHECKIN = 9
CHECKOUT = 10
CONNECT = 11
COPY = 12
DEBUG = 13
LABEL = 14
LINK = 15
LOCK = 16
MERGE = 17
MKACTIVITY = 18
MKCALENDAR = 19
MKCOL = 20
MKREDIRECTREF = 21
MKWORKSPACE = 22
MOVE = 23
OPTIONS = 24
ORDERPATCH = 25
PATCH = 26
PRI = 27
PROPFIND = 28
PROPPATCH = 29
REBIND = 30
REPORT = 31
SEARCH = 32
SHOWMETHOD = 33
SPACEJUMP = 34
TEXTSEARCH = 35
TRACE = 36
TRACK = 37
UNBIND = 38
UNCHECKOUT = 39
UNLINK = 40
UNLOCK = 41
UPDATE = 42
UPDATEREDIRECTREF = 43
VERSION_CONTROL = 44



_HTTPSTARTSTOP = _descriptor.Descriptor(
  name='HttpStartStop',
  full_name='events.HttpStartStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTimestamp', full_name='events.HttpStartStop.startTimestamp', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stopTimestamp', full_name='events.HttpStartStop.stopTimestamp', index=1,
      number=2, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requestId', full_name='events.HttpStartStop.requestId', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peerType', full_name='events.HttpStartStop.peerType', index=3,
      number=4, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='events.HttpStartStop.method', index=4,
      number=5, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='events.HttpStartStop.uri', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteAddress', full_name='events.HttpStartStop.remoteAddress', index=6,
      number=7, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userAgent', full_name='events.HttpStartStop.userAgent', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statusCode', full_name='events.HttpStartStop.statusCode', index=8,
      number=9, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contentLength', full_name='events.HttpStartStop.contentLength', index=9,
      number=10, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='applicationId', full_name='events.HttpStartStop.applicationId', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instanceIndex', full_name='events.HttpStartStop.instanceIndex', index=11,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='instanceId', full_name='events.HttpStartStop.instanceId', index=12,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forwarded', full_name='events.HttpStartStop.forwarded', index=13,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=421,
)

_HTTPSTARTSTOP.fields_by_name['requestId'].message_type = dropsonde_dot_pb_dot_uuid__pb2._UUID
_HTTPSTARTSTOP.fields_by_name['peerType'].enum_type = _PEERTYPE
_HTTPSTARTSTOP.fields_by_name['method'].enum_type = _METHOD
_HTTPSTARTSTOP.fields_by_name['applicationId'].message_type = dropsonde_dot_pb_dot_uuid__pb2._UUID
DESCRIPTOR.message_types_by_name['HttpStartStop'] = _HTTPSTARTSTOP
DESCRIPTOR.enum_types_by_name['PeerType'] = _PEERTYPE
DESCRIPTOR.enum_types_by_name['Method'] = _METHOD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HttpStartStop = _reflection.GeneratedProtocolMessageType('HttpStartStop', (_message.Message,), dict(
  DESCRIPTOR = _HTTPSTARTSTOP,
  __module__ = 'dropsonde.pb.http_pb2'
  # @@protoc_insertion_point(class_scope:events.HttpStartStop)
  ))
_sym_db.RegisterMessage(HttpStartStop)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!org.cloudfoundry.dropsonde.eventsB\013HttpFactory'))
# @@protoc_insertion_point(module_scope)
